containertools.replace_container_slice_with_rests
=================================================

.. autofunction:: abjad.tools.containertools.replace_container_slice_with_rests.replace_container_slice_with_rests
   :noindex:
